[Zodb-checkins] CVS: ZODB3/zdaemon - zdrun.py:1.2

Guido van Rossum guido@python.org
Sun, 19 Jan 2003 09:32:46 -0500


Update of /cvs-repository/ZODB3/zdaemon
In directory cvs.zope.org:/tmp/cvs-serv21530

Modified Files:
	zdrun.py 
Log Message:
Change more uses of "zdaemon.py" to "zdrun.py".


=== ZODB3/zdaemon/zdrun.py 1.1 => 1.2 ===
--- ZODB3/zdaemon/zdrun.py:1.1	Sat Jan 18 21:25:15 2003
+++ ZODB3/zdaemon/zdrun.py	Sun Jan 19 09:32:43 2003
@@ -12,10 +12,10 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
 """zdaemon -- run an application as a daemon.
 
-Usage: python zdaemon.py [zdaemon-options] program [program-arguments]
-Or:    python zdaemon.py -c [command]
+Usage: python zrdun.py [zrdun-options] program [program-arguments]
+Or:    python zrdun.py -c [command]
 
 Options:
   -b SECONDS -- set backoff limit to SECONDS (default 10; see below)
@@ -106,7 +106,7 @@
     errors related to the command line.
     """
 
-    progname = "zdaemon.py"             # Program name for usage message
+    progname = "zrdun.py"             # Program name for usage message
 
     # Options we know of, and their defaults
     backofflimit = 10                   # -b SECONDS
@@ -128,7 +128,7 @@
         args     -- the command line arguments, less the program name
                     (default is sys.argv[1:] at the time of call)
 
-        progname -- the program name (default "zdaemon.py")
+        progname -- the program name (default "zrdun.py")
         """
 
         if args is None:
@@ -414,7 +414,7 @@
         else:
             if not data.endswith("\n"):
                 data += "\n"
-            msg = ("Another zdaemon is already up using socket %r:\n%s" %
+            msg = ("Another zrdun is already up using socket %r:\n%s" %
                    (self.options.sockname, data))
             sys.stderr.write(msg)
             critical(msg)
@@ -12,10 +12,10 @@
 #
 ##############################################################################
-"""zdaemon -- run an application as a daemon.
+"""zrdun -- run an application as a daemon.
 